@@ -108,7 +108,7 @@ mod tests {
             amount: 100u64.into(),
         };
         contact
-            .send_tokens(send.clone(), Some(send), destination, key, Some(TIMEOUT))
+            .send_coins(send.clone(), Some(send), destination, Some(TIMEOUT), key)
             .await
             .unwrap();
     }
